# -*- coding: utf-8 -*-
"""Module where all interfaces, events and exceptions live."""

from zope.publisher.interfaces.browser import IDefaultBrowserLayer


class ICollectiveRelationfieldwidgetLayer(IDefaultBrowserLayer):
    """Marker interface that defines a browser layer."""

from plone.app.z3cform.interfaces import IRelatedItemsWidget

class IRelationWidget(IRelatedItemsWidget):
   """Marker interface for RelationWidget"""



# -*- coding: utf-8 -*-
import logging
from Acquisition import ImplicitAcquisitionWrapper
from Products.CMFCore.utils import getToolByName
from z3c.form.interfaces import IFieldWidget
from z3c.form.widget import FieldWidget
from zope.component.hooks import getSite
from zope.interface import implementer
from zope.interface import implementsOnly
from plone.app.z3cform.interfaces import IRelatedItemsWidget
from plone.app.z3cform.widget import RelatedItemsWidget
LOG = logging.getLogger(__name__)

class RelationWidget(RelatedItemsWidget):
    """RelatedItems widget for z3c.form with clickable list of URLs as output"""

    implementsOnly(IRelatedItemsWidget)

    def related_items(self):
        res = ()
        # Dexterity
        try:
            catalog = getToolByName(self.context, 'portal_catalog')
        except AttributeError:
            catalog = getToolByName(getSite(), 'portal_catalog')
        separator = self.separator
        if not self.value:
            return ()
        related = self.value.split(separator)
        if not related:
            return ()
        res = catalog(UID=related)
        return res


@implementer(IFieldWidget)
def RelationFieldWidget(field, request, extra=None):
    if extra is not None:
        request = extra
    return FieldWidget(field, RelationWidget(request))





# -*- coding: utf-8 -*-
"""Installer for the collective.relationfieldwidget package."""

from setuptools import find_packages
from setuptools import setup


long_description = (
    open('README.rst').read() +
    '\n' +
    'Contributors\n' +
    '============\n' +
    '\n' +
    open('CONTRIBUTORS.rst').read() +
    '\n' +
    open('CHANGES.rst').read() +
    '\n')


setup(
    name='collective.relationfieldwidget',
    version='1.0a1',
    description="RelationField Widget for Plone 5",
    long_description=long_description,
    # Get more from https://pypi.python.org/pypi?%3Aaction=list_classifiers
    classifiers=[
        "Environment :: Web Environment",
        "Framework :: Plone",
        "Framework :: Plone :: 5.0",
        "Programming Language :: Python",
        "Programming Language :: Python :: 2.7",
        "Operating System :: OS Independent",
        "License :: OSI Approved :: GNU General Public License v2 (GPLv2)",
    ],
    keywords='Python Plone',
    author='Matt Grant',
    author_email='matt.grant@foodstuffs-si.co.nz',
    url='https://pypi.python.org/pypi/collective.relationfieldwidget',
    license='GPL',
    packages=find_packages(exclude=['ez_setup']),
    namespace_packages=['collective'],
    include_package_data=True,
    zip_safe=False,
    install_requires=[
        'setuptools',
        'Acquisition',
        'Products.CMFCore',
        'Products.CMFPlone',
        'plone.app.z3cform'
    ],
    extras_require={
        'tests': [
            'plone.app.testing',
            'plone.browserlayer',
            'plone.testing',
            'zope.contentprovider',
            'zope.publisher',
            'zope.testing',
        ]
    },
    entry_points="""
    [z3c.autoinclude.plugin]
    target = plone
    """,
)
